@@ -62,6 +62,27 @@ fn main() -> Result<(), ExitFailure> {
                                     key, value_type
                                 ))?
                             ),
+                            "list" => format!(
+                                "= {:?}",
+                                lrange(&mut connection, key, 0, -1).with_context(|_| format!(
+                                    "using lrange on the key `{}` ({})",
+                                    key, value_type
+                                ))?
+                            ),
+                            "set" => format!(
+                                "= {:?}",
+                                smembers(&mut connection, key).with_context(|_| format!(
+                                    "using smembers on the key `{}` ({})",
+                                    key, value_type
+                                ))?
+                            ),
+                            "zset" => format!(
+                                "= {:?}",
+                                zrange(&mut connection, key, 0, -1).with_context(|_| format!(
+                                    "using zrange on the key `{}` ({})",
+                                    key, value_type
+                                ))?
+                            ),
                             "hash" => format!(
                                 "= {:?}",
                                 hgetall(&mut connection, key).with_context(|_| format!(
@@ -69,7 +90,7 @@ fn main() -> Result<(), ExitFailure> {
                                     key, value_type
                                 ))?
                             ),
-                            _ => format!("type {} not supported.", value_type),
+                            _ => format!(":: type `{}` not supported.", value_type),
                         }
                     } else {
                         String::new()
